@@ -1,8 +1,11 @@
-from urllib.parse import urljoin
 from django.conf import settings
 from PIL import Image
 import os
 
+try:
+    from urllib.parse import urljoin
+except ImportError:
+    from urlparse import urljoin
 
 class ImageDescriptor(object):
     name = None
