@@ -7,8 +7,8 @@ register = template.Library()
 
 @register.assignment_tag()
 def process_image(image, **options):
-    try:
-        engine = get_engine()
-        return engine.process_image(image, **options)
-    except Exception as e:
-        pass
+    # try:
+    engine = get_engine()
+    return engine.process_image(image, **options)
+    # except Exception as e:
+    #     pass
